@@ -8,6 +8,7 @@ class Nonces(object):
     ApplePayVisa = "fake-apple-pay-visa-nonce"
     ApplePayMasterCard = "fake-apple-pay-mastercard-nonce"
     ApplePayAmEx = "fake-apple-pay-amex-nonce"
+    ApplePayMpan = "fake-apple-pay-mpan-nonce"
     AbstractTransactable = "fake-abstract-transactable-nonce"
     Europe = "fake-europe-bank-account-nonce"
     # NEXT_MAJOR_VERSION - rename AndroidPay to GooglePay
@@ -69,6 +70,8 @@ class Nonces(object):
     MasterpassDiscover = "fake-masterpass-discover-nonce"
     MasterpassMasterCard = "fake-masterpass-mastercard-nonce"
     MasterpassVisa = "fake-masterpass-visa-nonce"
+    MetaCheckoutCard = "fake-meta-checkout-card-nonce"
+    MetaCheckoutToken = "fake-meta-checkout-token-nonce"
     VisaCheckoutAmEx = "fake-visa-checkout-amex-nonce"
     VisaCheckoutDiscover = "fake-visa-checkout-discover-nonce"
     VisaCheckoutMasterCard = "fake-visa-checkout-mastercard-nonce"
@@ -78,3 +81,4 @@ class Nonces(object):
     SamsungPayMasterCard = "tokensam_fake_mastercard"
     SamsungPayVisa = "tokensam_fake_visa"
     SepaDirectDebit = "fake-sepa-direct-debit-nonce"
+    UsBankAccount = "fake-us-bank-account-nonce"
